/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2009 Jaroslav Tulach
 */

package cz.xelfi.quoridor.webidor.resources;

import cz.xelfi.quoridor.webidor.*;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Properties;
import java.util.logging.Logger;
import javax.ws.rs.DefaultValue;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.QueryParam;
import javax.ws.rs.core.MediaType;

/**
 *
 * @author Jaroslav Tulach <jtulach@netbeans.org>
 */
public final class Users {
    private final Quoridor quoridor;
    private final File dir;
    private static final Logger LOG = Logger.getLogger(Users.class.getName());

    Users(File dir, Quoridor quoridor) {
        this.dir = dir;
        this.quoridor = quoridor;
        dir.mkdirs();
    }

    @GET
    @Path("{id}")
    @Produces({ MediaType.APPLICATION_JSON, MediaType.TEXT_XML })
    public User getUserInfo(
        @QueryParam("loginID") String loginId,
        @PathParam("id") String id
    ) throws IOException {
        String  myid = quoridor.isLoggedIn(loginId);
        Properties myp = getProp(myid);
        Properties p = getProp(id);
        User user = new User(id);
        for (String n : p.stringPropertyNames()) {
            if (n.startsWith("permission.")) {
                continue;
            }
            if (!id.equals(myid) && !"true".equals(myp.getProperty("permission." + n))) {
                continue;
            }
            user.addProperty(n, p.getProperty(n));
        }
        return user;
    }

    private Properties getProp(String id) throws FileNotFoundException, IOException {
        Properties p = new Properties();
        if (id != null && id.length() > 0) {
            File f = new File(dir, id);
            FileInputStream is = new FileInputStream(f);
            p.load(is);
            is.close();
        }
        return p;
    }
}
